package com.zehong.dangerousdevicereport.service.impl;

import cn.hutool.core.date.DateUtil;
import com.zehong.dangerousdevicereport.dao.SafetyDeviceInfoDao;
import com.zehong.dangerousdevicereport.entity.SafetyDeviceInfo;
import com.zehong.dangerousdevicereport.service.ISafetyDeviceInfoService;
import org.springframework.stereotype.Service;
import javax.annotation.Resource;
import java.util.List;

/**
 * 企业安全监测设备Service业务层处理
 * 
 * @author zehong
 * @date 2022-04-12
 */
@Service
public class SafetyDeviceInfoServiceImpl implements ISafetyDeviceInfoService {

    @Resource
    private SafetyDeviceInfoDao safetyDeviceInfoDao;

    /**
     * 查询企业安全监测设备
     * 
     * @param id 企业安全监测设备ID
     * @return 企业安全监测设备
     */
    @Override
    public SafetyDeviceInfo selectSafetyDeviceInfoById(String id){
        return safetyDeviceInfoDao.selectSafetyDeviceInfoById(id);
    }

    /**
     * 查询企业安全监测设备列表
     * 
     * @param safetyDeviceInfo 企业安全监测设备
     * @return 企业安全监测设备
     */
    @Override
    public List<SafetyDeviceInfo> selectSafetyDeviceInfoList(SafetyDeviceInfo safetyDeviceInfo){
        return safetyDeviceInfoDao.selectSafetyDeviceInfoList(safetyDeviceInfo);
    }

    /**
     * 新增企业安全监测设备
     * 
     * @param safetyDeviceInfo 企业安全监测设备
     * @return 结果
     */
    @Override
    public int insertSafetyDeviceInfo(SafetyDeviceInfo safetyDeviceInfo){
        safetyDeviceInfo.setCreateTime(DateUtil.date());
        return safetyDeviceInfoDao.insertSafetyDeviceInfo(safetyDeviceInfo);
    }

    /**
     * 修改企业安全监测设备
     * 
     * @param safetyDeviceInfo 企业安全监测设备
     * @return 结果
     */
    @Override
    public int updateSafetyDeviceInfo(SafetyDeviceInfo safetyDeviceInfo){
        safetyDeviceInfo.setUpdateTime(DateUtil.date());
        return safetyDeviceInfoDao.updateSafetyDeviceInfo(safetyDeviceInfo);
    }

    /**
     * 批量删除企业安全监测设备
     * 
     * @param ids 需要删除的企业安全监测设备ID
     * @return 结果
     */
    @Override
    public int deleteSafetyDeviceInfoByIds(String[] ids){
        return safetyDeviceInfoDao.deleteSafetyDeviceInfoByIds(ids);
    }

    /**
     * 删除企业安全监测设备信息
     * 
     * @param id 企业安全监测设备ID
     * @return 结果
     */
    @Override
    public int deleteSafetyDeviceInfoById(String id){
        return safetyDeviceInfoDao.deleteSafetyDeviceInfoById(id);
    }
}
