package com.zehong.dangerousdevicereport.service.impl;

import java.util.Date;
import java.util.List;

import com.zehong.dangerousdevicereport.dao.TDeviceReportDataDao;
import com.zehong.dangerousdevicereport.entity.TDeviceReportData;
import com.zehong.dangerousdevicereport.service.ITDeviceReportDataService;
import org.springframework.stereotype.Service;
import javax.annotation.Resource;

/**
 * 设备信息上报Service业务层处理
 * 
 * @author zehong
 * @date 2022-04-11
 */
@Service
public class TDeviceReportDataServiceImpl implements ITDeviceReportDataService {
    @Resource
    private TDeviceReportDataDao tDeviceReportDataDao;

    /**
     * 查询设备信息上报
     * 
     * @param reportId 设备信息上报ID
     * @return 设备信息上报
     */
    @Override
    public TDeviceReportData selectTDeviceReportDataById(String reportId){
        return tDeviceReportDataDao.selectTDeviceReportDataById(reportId);
    }

    /**
     * 查询设备信息上报列表
     * 
     * @param tDeviceReportData 设备信息上报
     * @return 设备信息上报
     */
    @Override
    public List<TDeviceReportData> selectTDeviceReportDataList(TDeviceReportData tDeviceReportData){
        return tDeviceReportDataDao.selectTDeviceReportDataList(tDeviceReportData);
    }

    /**
     * 新增设备信息上报
     * 
     * @param tDeviceReportData 设备信息上报
     * @return 结果
     */
    @Override
    public int insertTDeviceReportData(TDeviceReportData tDeviceReportData){
        tDeviceReportData.setReportTime(new Date());
        return tDeviceReportDataDao.insertTDeviceReportData(tDeviceReportData);
    }

    /**
     * 修改设备信息上报
     * 
     * @param tDeviceReportData 设备信息上报
     * @return 结果
     */
    @Override
    public int updateTDeviceReportData(TDeviceReportData tDeviceReportData){
        return tDeviceReportDataDao.updateTDeviceReportData(tDeviceReportData);
    }

    /**
     * 批量删除设备信息上报
     * 
     * @param reportIds 需要删除的设备信息上报ID
     * @return 结果
     */
    @Override
    public int deleteTDeviceReportDataByIds(String[] reportIds){
        return tDeviceReportDataDao.deleteTDeviceReportDataByIds(reportIds);
    }

    /**
     * 删除设备信息上报信息
     * 
     * @param reportId 设备信息上报ID
     * @return 结果
     */
    @Override
    public int deleteTDeviceReportDataById(String reportId){
        return tDeviceReportDataDao.deleteTDeviceReportDataById(reportId);
    }

    /**
     * 清楚历史数据
     * @param reportTime 上报时间
     * @return
     */
    @Override
    public int clearHistoryReportedData(String reportTime){
        return tDeviceReportDataDao.clearHistoryReportedData(reportTime);
    }
}
